@@ -61,6 +61,10 @@ class GammaExponential:
     def predict(self, x):
         return stats.lomax.cdf(1.0 / x, self.alpha, scale=1.0 / self.beta)
 
+    def sample(self,n=1):
+        lamda = np.random.gamma(self.alpha, 1/self.beta)
+        return np.random.exponential(1/lamda,n)
+
 
 class GammaPoisson(GammaExponential):
     def update(self, *args):
@@ -73,3 +77,7 @@ class GammaPoisson(GammaExponential):
 
     def predict(self, x):
         return stats.nbinom.pmf(x, self.alpha, scale=1.0 / (1 + self.beta))
+
+    def sample(self,n=1):
+        lamda = np.random.gamma(self.alpha, 1/self.beta)
+        return np.random.poisson(lamda,n)
